==> gthumb-2.12.3-i486-72.1.txz: install/doinst.sh <==
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/preferences.png preferences.png )

==> gthumb-2.14.3-i486-72.1.txz: install/doinst.sh <==
( cd usr/share/gnome/help/gthumb/eu/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/eu/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/oc/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/sl/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/sv/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/es/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/es/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/de/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/de/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/el/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/el/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/fr/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf specific-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/specific-filter.png specific-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/thumbnail-pane.png thumbnail-pane.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf main-win.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/main-win.png main-win.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import.png import.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf comment.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/comment.png comment.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf palette.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/palette.png palette.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import-pref-auto-folder.png import-pref-auto-folder.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/import-pref-custom-format.png import-pref-custom-format.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf general-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/general-filter.png general-filter.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf nav-button.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/nav-button.png nav-button.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; rm -rf preferences.png )
( cd usr/share/gnome/help/gthumb/zh_CN/figures ; ln -sf ../../C/figures/preferences.png preferences.png )
